
# Energytool

<p align="center">
  <img src="https://raw.githubusercontent.com/BuildingEnergySimulationTools/energytool/main/logo_energytool.svg" alt="Energytool" width="200"/>
</p>

[![PyPI](https://img.shields.io/pypi/v/python-tide?label=pypi%20package)](https://pypi.org/project/python-tide/)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
![Static Badge](https://img.shields.io/badge/python-3.10_%7C_3.12-blue)
[![License](https://img.shields.io/badge/License-BSD_3--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)


Python module to wrap EnergyPlus for CorrAI :
- <code>Building</code> class to simulate HVAC systems through pre-process and post process methods
- Basic HVAC model
- Modifier function for parametric simulation
- Allows Pandas <code>DataFrame</code> as boundary conditions